[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,151 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#ifndef __COMMON_UTILITY_H__
#define __COMMON_UTILITY_H__
#include <cuda_runtime_api.h>
// cuda_runtime_api needs to come first
#include <cuda/__runtime/api_wrapper.h>
#include <cuda/__stream/stream_ref.h>
#include <cuda/atomic>
#include <cuda/std/utility>
#include <cuda/experimental/launch.cuh>
#include <new> // IWYU pragma: keep (needed for placement new)
#include "testing.cuh"
namespace
{
namespace test
{
constexpr auto one_thread_dims = cuda::make_config(cuda::block_dims<1>(), cuda::grid_dims<1>());
struct _malloc_pinned
{
private:
void* pv = nullptr;
public:
explicit _malloc_pinned(std::size_t size)
{
cuda::__ensure_current_context guard(cuda::device_ref{0});
_CCCL_TRY_CUDA_API(::cudaMallocHost, "failed to allocate pinned memory", &pv, size);
}
~_malloc_pinned()
{
cuda::__ensure_current_context guard(cuda::device_ref{0});
[[maybe_unused]] auto status = ::cudaFreeHost(pv);
}
template <class T>
T* get_as() const noexcept
{
return static_cast<T*>(pv);
}
};
template <class T>
struct pinned
{
private:
_malloc_pinned _mem;
public:
explicit pinned(T t)
: _mem(sizeof(T))
{
::new (_mem.get_as<void>()) T(std::move(t));
}
~pinned()
{
get()->~T();
}
T* get() noexcept
{
return _mem.get_as<T>();
}
const T* get() const noexcept
{
return _mem.get_as<T>();
}
T& operator*() noexcept
{
return *get();
}
const T& operator*() const noexcept
{
return *get();
}
};
template <int N>
struct assign_n
{
__device__ constexpr void operator()(int* pi) const noexcept
{
*pi = N;
}
};
template <int N>
struct verify_n
{
__device__ void operator()(int* pi) const noexcept
{
REQUIRE_DEVICE(*pi == N);
}
};
using assign_42 = assign_n<42>;
using verify_42 = verify_n<42>;
struct atomic_add_one
{
__device__ void operator()(int* pi) const noexcept
{
cuda::atomic_ref atomic_pi(*pi);
atomic_pi.fetch_add(1);
}
};
struct atomic_sub_one
{
__device__ void operator()(int* pi) const noexcept
{
cuda::atomic_ref atomic_pi(*pi);
atomic_pi.fetch_sub(1);
}
};
struct spin_until_80
{
__device__ void operator()(int* pi) const noexcept
{
cuda::atomic_ref atomic_pi(*pi);
while (atomic_pi.load() != 80)
;
}
};
struct empty_kernel
{
__device__ void operator()() const noexcept {}
};
} // namespace test
} // namespace
#endif // __COMMON_UTILITY_H__